==> haskell-casa-types-0.0.3-13.1-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-casa-types.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 casa-types
version:              0.0.3
visibility:           public
id:                   casa-types-0.0.3-ET20ZjvITV2HyXRhd7dUO7
key:                  casa-types-0.0.3-ET20ZjvITV2HyXRhd7dUO7
license:              BSD-3-Clause
copyright:
    2018-2019 FP Complete,
    2024-2025 Haskell Foundation

maintainer:
    Chris Done <chrisdone@fpcomplete.com>,
    Mike Pilgrem <public@pilgrem.com>

author:               Chris Done
homepage:             https://github.com/commercialhaskell/casa#readme
synopsis:             Types for Casa
description:
    Types for Casa (Content-Addressable Storage Archive). See
    <https://casa.stackage.org/>

category:             Development
abi:                  fe274fd8aa117c72b0fd730ca73947cf
exposed:              True
exposed-modules:      Casa.Types
import-dirs:          /usr/lib/ghc-9.6.6/site-local/casa-types-0.0.3
library-dirs:         /usr/lib/ghc-9.6.6/site-local/casa-types-0.0.3
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/casa-types-0.0.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-casa-types
hs-libraries:         HScasa-types-0.0.3-ET20ZjvITV2HyXRhd7dUO7
depends:
    aeson-2.1.2.1-GojnAvr1Jep10WUNi5H1Pi
    attoparsec-0.14.4-8gkbEkDkw506qTMOo0v2nm base-4.18.2.1
    base16-bytestring-1.0.2.0-Dwd5n4mSUH32rjuqPFOreR
    bytestring-0.11.5.3 hashable-1.4.7.0-DKTv0aQgcZmBEMi2BPTV4Z
    path-pieces-0.2.1-ILPSumWqTsA51OyVDS7ISl
    persistent-2.14.5.2-LW4wp3jmP881UTaaXowY4R text-2.0.2

haddock-interfaces:   /usr/share/doc/haskell-casa-types/html/casa-types.haddock
haddock-html:         /usr/share/doc/haskell-casa-types/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-casa-types-0.0.3-15-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-casa-types.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 casa-types
version:              0.0.3
visibility:           public
id:                   casa-types-0.0.3-9s1eRoPqUMAI0rFVV9RayN
key:                  casa-types-0.0.3-9s1eRoPqUMAI0rFVV9RayN
license:              BSD-3-Clause
copyright:
    2018-2019 FP Complete,
    2024-2025 Haskell Foundation

maintainer:
    Chris Done <chrisdone@fpcomplete.com>,
    Mike Pilgrem <public@pilgrem.com>

author:               Chris Done
homepage:             https://github.com/commercialhaskell/casa#readme
synopsis:             Types for Casa
description:
    Types for Casa (Content-Addressable Storage Archive). See
    <https://casa.stackage.org/>

category:             Development
abi:                  41a4cb958cbae716bcabc26bdcd294c8
exposed:              True
exposed-modules:      Casa.Types
import-dirs:          /usr/lib/ghc-9.6.6/site-local/casa-types-0.0.3
library-dirs:         /usr/lib/ghc-9.6.6/site-local/casa-types-0.0.3
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/casa-types-0.0.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-casa-types
hs-libraries:         HScasa-types-0.0.3-9s1eRoPqUMAI0rFVV9RayN
depends:
    aeson-2.1.2.1-CpIoOLI7lIpJkSqSOmDN9y
    attoparsec-0.14.4-68EOoedQqwu8mpKj0RmtvE base-4.18.2.1
    base16-bytestring-1.0.2.0-ARBAmNNbyxLEDoUwDjra0R
    bytestring-0.11.5.3 hashable-1.4.7.0-1GSULm1uRgQBgX6mu6tvYD
    path-pieces-0.2.1-ILPSumWqTsA51OyVDS7ISl
    persistent-2.14.5.2-9eq8y6ZCNqR84OxLjl0e2k text-2.0.2

haddock-interfaces:   /usr/share/doc/haskell-casa-types/html/casa-types.haddock
haddock-html:         /usr/share/doc/haskell-casa-types/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
